==========
Categories
==========

The following methods are available under the `Series.cat` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Series.cat.ends_with
    Series.cat.get_categories
    Series.cat.is_local
    Series.cat.len_bytes
    Series.cat.len_chars
    Series.cat.starts_with
    Series.cat.to_local
    Series.cat.uses_lexical_ordering
